Crate use_oci_layer

Crate use_oci_layer 

use-oci-layer

use-oci-layer provides OCI layer primitives for media types, compression markers, layer size, diff IDs, and layer kind metadata.

It is part of the use-oci RustUse workspace for small, focused OCI primitive crates. It does not perform network calls, shell out to runtimes, implement a registry client, or build container images.

License

Licensed under either of the following, at your option:

  • Apache License, Version 2.0
  • MIT license

Structs

DiffId
A layer diff ID digest marker.
LayerMediaType
An OCI layer media type.
LayerSize
Layer size in bytes.
OciLayer
OCI layer metadata. This type does not extract or decompress layers.

Enums

LayerCompression
OCI layer compression labels.
LayerError
Errors returned when OCI layer metadata is invalid.
LayerKind
OCI layer kind labels.